/***************************************
 *                                     *
 *  JBoss: The OpenSource J2EE WebOS   *
 *                                     *
 *  Distributable under LGPL license.  *
 *  See terms of license at gnu.org.   *
 *                                     *
 ***************************************/

package org.jboss.monitor;

import java.util.Map;
import java.util.HashMap;

/**
 * This class encapsulates the specification of a log file's rollover period.
 */
class RolloverPeriod
{
    private static final String BASE_FORMAT    = "\'.\'yyyy";
    private static final String MONTH_FORMAT   = BASE_FORMAT + "-MM";
    private static final String WEEK_FORMAT    = BASE_FORMAT + "-ww";
    private static final String DAY_FORMAT     = MONTH_FORMAT + "-dd";
    private static final String HALFDAY_FORMAT = DAY_FORMAT + "-a";
    private static final String HOUR_FORMAT    = DAY_FORMAT + "-HH";
    private static final String MINUTE_FORMAT  = HOUR_FORMAT + "-mm";

    private static final Map PERIOD_FORMATS;

    static
    {
        PERIOD_FORMATS = new HashMap();
        PERIOD_FORMATS.put("MONTH", MONTH_FORMAT);
        PERIOD_FORMATS.put("MONTHLY", MONTH_FORMAT);
        PERIOD_FORMATS.put("WEEK", WEEK_FORMAT);
        PERIOD_FORMATS.put("WEEKLY", WEEK_FORMAT);
        PERIOD_FORMATS.put("DAY", DAY_FORMAT);
        PERIOD_FORMATS.put("DAILY", DAY_FORMAT);
        PERIOD_FORMATS.put("HALFDAY", HALFDAY_FORMAT);
        PERIOD_FORMATS.put("HALFDAILY", HALFDAY_FORMAT);
        PERIOD_FORMATS.put("HOUR", HOUR_FORMAT);
        PERIOD_FORMATS.put("HOURLY", HOUR_FORMAT);
        PERIOD_FORMATS.put("MINUTE", MINUTE_FORMAT);
    }

    private String _rolloverPeriod;
    private String _rolloverFormat;

    /**
     * Constructor.
     *
     * @param rolloverPeriod a rollover period specification.
     */
    public RolloverPeriod(String rolloverPeriod)
    {
        _rolloverFormat =
            (String) PERIOD_FORMATS.get(rolloverPeriod.toUpperCase());

        if (_rolloverFormat == null)
        {
            final String message =
                "Unknown rollover period: " + rolloverPeriod + ".";

            throw new IllegalArgumentException(message);
        }

        _rolloverPeriod = rolloverPeriod;
    }

    /**
     * Returns the rollover format specification associated with the rollover
     * period specification used to construct this class.
     */
    public String getRolloverFormat()
    {
        return _rolloverFormat;
    }

    /**
     * Returns the rollover period specification used to construct this class.
     */
    public String toString()
    {
        return _rolloverPeriod;
    }
}
